(***********************************************************************)
(*                                                                     *)
(*                                OCaml                                *)
(*                                                                     *)
(*            Xavier Leroy, projet Cristal, INRIA Rocquencourt         *)
(*                                                                     *)
(*  Copyright 1996 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the Q Public License version 1.0.               *)
(*                                                                     *)
(***********************************************************************)

(* $Id: parsetree.mli 12511 2012-05-30 13:29:48Z lefessan $ *)

(* Abstract syntax tree produced by parsing *)

open Asttypes

(* Value expressions for the core language *)

type pattern =
  { ppat_desc: string;
    ppat_loc: Location.t }

type expression =
  { pexp_desc: expression_desc;
    pexp_loc: Location.t }

and expression_desc =
    Pexp_ident of ident loc                        (* variable           *)
  | Pexp_constant of constant                      (* integer constant   *)
  | Pexp_let of rec_flag * pattern * expression * expression
                                                   (* let ... in ...     *)
  | Pexp_function of pattern * expression          (* fun ... -> ...     *)
  | Pexp_apply of expression * expression          (* /!\ (a f) for f(a) *)

